==> CosmoTech_SupplyChain-2.1.10-py3-none-any.whl: Supplychain/Schema/simulator_files_description.py <==
simulator_format = {
    'ModelParameters': [
        "TimeStepDuration",
        "TimeStepPerCycle",
        "NumberOfCycle",
        "StartingDate",
        "ManageBacklogQuantities",
        "OptimizationObjective",
        "ActivateUncertainties",
        "EmptyObsoleteStocks",
        "UncertaintiesProbabilityDistribution",
        "ActivateVariableMachineOpeningRate",
        "ImmobilizedCashRelativeCost",
        "BatchSize",
        "ExtraProductionPlanIsAvailable",
        "EnforceProductionPlan",
    ],
    'BE_Stock': [
        "Name",
        "CurrentStock",
        "MinimalStock",
        "MaximalStock",
        "Value",
        "PurchasingUnitCost",
        "CO2UnitEmissions",
        "UnitIncome",
        "Demand",
        "StorageUnitCostSchedule",
        "IsInfinite",
        "StockPolicy",
        "SourcingPolicy",
        "DispatchPolicy",
        "OrderPointSchedule",
        "OrderQuantitySchedule",
        "SchedulingStep",
    ],
    'CE_Machine': [
        "Name",
        "StockTypeProportion",
        "Groups",
        "OpeningRates",
        "OpeningTimeSchedule",
        "ProductionCostSchedule",
        "ProductionPolicy",
    ],
    'BE_Operation': [
        "Name",
        "ParentName",
        "OperatingPerformanceSchedule",
        "CycleTimeSchedule",
        "RejectRateSchedule",
        "OperatingPerformanceUncertaintySchedule",
        "ProductionUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "ProductionPlanSchedule",
        "InvestmentCost",
        "IsContractor",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
    ],
    'BE_TransportOperation': [
        "Name",
        "TransportDuration",
        "InitialTransportQuantity",
        "InitialTransportValue",
        "TransportUnitCostSchedule",
        "CustomsUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
    ],
    'EE_StockToOperation': [
        "Name",
        "OperationName",
        "StockName",
        "PropStockForOperation",
        "IsProportion",
        "Groups",
        "Cardinality",
    ],
    'Arcs_OperationToStock': [
        "StockName",
        "OperationName",
    ],
    'IndustrialNetworkScheduler': [
        "Name",
        "Type",
        "TaskName",
    ]
}

==> CosmoTech_SupplyChain-3.2.0-py3-none-any.whl: Supplychain/Schema/simulator_files_description.py <==
simulator_format = {
    "ModelParameters": [
        "TimeStepDuration",
        "TimeStepPerCycle",
        "NumberOfCycle",
        "StartingDate",
        "ManageBacklogQuantities",
        "OptimizationObjective",
        "ActivateUncertainties",
        "EmptyObsoleteStocks",
        "UncertaintiesProbabilityDistribution",
        "TransportUncertaintiesProbabilityDistribution",
        "ActivateVariableMachineOpeningRate",
        "ImmobilizedCashRelativeCost",
        "BatchSize",
        "ExtraProductionPlanIsAvailable",
        "EnforceProductionPlan",
        "ActualizeShipments",
        "ActivateCorrelatedDemandUncertainties",
        "DemandCorrelations",
    ],
    "BE_Stock": [
        "Name",
        "CurrentStock",
        "MinimalStock",
        "MaximalStock",
        "Value",
        "PurchasingUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "UnitIncomeSchedule",
        "Demand",
        "StorageUnitCostSchedule",
        "IsInfinite",
        "StockPolicy",
        "SourcingPolicy",
        "DispatchPolicy",
        "ReviewPeriod",
        "FirstReview",
        "Advance",
        "LeadTime",
        "SalesForecasts",
        "OrderPointSchedule",
        "OrderQuantitySchedule",
        "SafetyQuantitySchedule",
        "SchedulingStep",
    ],
    "CE_Machine": [
        "Name",
        "StockTypeProportion",
        "Groups",
        "OpeningRates",
        "OpeningTimeSchedule",
        "ProductionCostSchedule",
        "ProductionPolicy",
    ],
    "BE_Operation": [
        "Name",
        "ParentName",
        "OperatingPerformanceSchedule",
        "CycleTimeSchedule",
        "RejectRateSchedule",
        "OperatingPerformanceUncertaintySchedule",
        "ProductionUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "ProductionPlanSchedule",
        "InvestmentCost",
        "IsContractor",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
        "Duration",
        "LeadTime",
        "MinimumOrderQuantitySchedule",
        "MultipleOrderQuantitySchedule",
        "SourcingProportionSchedule",
    ],
    "BE_TransportOperation": [
        "Name",
        "Duration",
        "Shipments",
        "TransportUnitCostSchedule",
        "CustomsUnitCostSchedule",
        "CO2UnitEmissionsSchedule",
        "Priority",
        "SchedulingStep",
        "FollowsStockPolicy",
        "LeadTime",
        "ActualDurationSchedule",
        "MinimumOrderQuantitySchedule",
        "MultipleOrderQuantitySchedule",
        "SourcingProportionSchedule",
        "TransportUncertaintiesParameter1",
        "TransportUncertaintiesParameter2",
        "TransportUncertaintiesParameter3",
        "TransportUncertaintiesParameter4",
    ],
    "EE_StockToOperation": [
        "Name",
        "OperationName",
        "StockName",
        "PropStockForOperation",
        "IsProportion",
        "Groups",
        "Cardinality",
    ],
    "Arcs_OperationToStock": [
        "StockName",
        "OperationName",
    ],
    "IndustrialNetworkScheduler": [
        "Name",
        "Type",
        "TaskName",
    ],
}
